// test_detect_charset.cpp : Defines the entry point for the console application.
//

#include "stdio.h"
#include "stdlib.h"
#include "myx_public_interface.h"

char * filename_in1= "index.txt";

int main()
{
  char filename[256];
  FILE *file= fopen(filename_in1,"r");
  if (file)
  {
    while (fgets(filename,sizeof(filename), file))
    {
      size_t len= strlen(filename);
      if (len>0)
      {
        for (char * pos= filename + len -1; 
             pos!=filename && (*pos=='\r' || *pos=='\n'); pos--)
        {
         *pos= 0;
        }
#ifndef _WINDOWS_
	{
	  for (char * pos= filename; *pos; pos++)
	  {
	    if  (*pos=='\\')
	      *pos= '/';
	  }
	}
#endif
      }
// charset autodetection was remmoved from library
#if 0
      const char * charset= myx_detect_charset_from_sql_file(filename);
      for (char * pos= filename; *pos; pos++)
      {
	if  (*pos=='\\' || *pos=='/')
	  *pos= '|';
      }
      printf("charset in file \"%s\" is \"%s\"\n",filename,charset);
      g_free((gpointer)charset);
#endif
    }
  }
  return 0;
}
